import { SupportedApiMethods } from "../interfaces/generics";
import { IBreadcrumbs, IMeta, IHead } from "../interfaces/breadCrumbs";
/**
 * Global api request class. Use this to put any api request through
 *
 * It needs to know of a token, which means you need to create one instance without token (pre auth)
 * and one instance with a token (post auth). Otherwise you are doomed.
 *
 * On the createRequest method: this one will take a FULL url. For example api.staging.gg/admin/createUser.
 *
 * Before it used to be a lot simpler intake, limited to the endpoint itself, such as /admin/createUser.
 *
 * However, since this is an abstraction, and yu can't or don't need to put the env here as well, you will need
 * to mod the requests as per this specification. Thank you!
 *  */
export declare class ApiRequest {
    token: string;
    constructor(token: string);
    setToken: (newToken: string) => void;
    requestHeaders: (additionalHeaders?: {
        [key: string]: string;
    } | undefined) => {
        "content-type": string;
        Authorization: string;
        accept: string;
    };
    getResponse: <Type>(response: Response) => Promise<{
        data: Type;
        statusCode: number;
        breadCrumbs: IBreadcrumbs;
        meta: IMeta;
        head: IHead;
    }>;
    createRequest: <Type>(method: SupportedApiMethods, endpoint: string, payload?: string, additionalHeaders?: {
        [key: string]: string;
    } | undefined) => Promise<{
        data: Type;
        statusCode: number;
    }>;
    get: <Type>(endpoint: string, additionalHeaders?: {
        [key: string]: string;
    } | undefined) => Promise<{
        data: Type;
        statusCode: number;
        breadCrumbs?: IBreadcrumbs | undefined;
        meta?: IMeta | undefined;
        head?: IHead | undefined;
    }>;
    put: <Type>(endpoint: string, payload?: string, additionalHeaders?: {
        [key: string]: string;
    } | undefined) => Promise<{
        data: Type;
        statusCode: number;
    }>;
    post: <Type>(endpoint: string, payload?: string, additionalHeaders?: {
        [key: string]: string;
    } | undefined) => Promise<{
        data: Type;
        statusCode: number;
    }>;
    delete: <Type>(endpoint: string, payload?: string, additionalHeaders?: {
        [key: string]: string;
    } | undefined) => Promise<{
        data: Type;
        statusCode: number;
    }>;
    patch: <Type>(endpoint: string, payload?: string, additionalHeaders?: {
        [key: string]: string;
    } | undefined) => Promise<{
        data: Type;
        statusCode: number;
    }>;
}
